package com.theitbulls.cameraex.camera2;

import android.media.Image;
import android.media.ImageReader;
import android.os.Environment;
import android.util.Log;

import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.text.SimpleDateFormat;
import java.util.Date;

public class ImageUtils {
    public enum FileType {JPG, MP4, MP3}

    public static File saveImage(ImageReader reader) {
        Image image = null;
        try {
            image = reader.acquireLatestImage();
            ByteBuffer buffer = image.getPlanes()[0].getBuffer();
            byte[] bytes = new byte[buffer.capacity()];
            buffer.get(bytes);
            return saveImage(bytes);
        } catch (Exception ee) {
        } finally {
            if (image != null) {
                image.close();
            }
        }

        return null;
    }

    private static File saveImage(byte[] bytes) {
        File fileLocation = getOutputMediaFile(FileType.JPG);
        OutputStream out = null;
        try {
            out = new FileOutputStream(fileLocation);
            out.write(bytes);
        } catch (Exception e) {
            Log.d("SaveFileError", e.toString());
        } finally {
            try {
                if (out != null) {
                    out.close();
                }
            } catch (Exception e) {
            }
        }

        return fileLocation;
    }

    public static File getOutputMediaFile(FileType type) {
        // make folder into external storage directory with name TheItBulls
        File mediaStorageDir = new File(Environment.getExternalStorageDirectory(), "TheItBulls");
        if (!mediaStorageDir.exists()) {
            if (!mediaStorageDir.mkdirs()) {
                Log.d("FolderCreationError", "Failed to create directory");
                return null;
            }
        }
        // Create a media file name
        String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
        String prefix = "image_";
        String ext = "jpg";
        if(type == FileType.MP3) {
            ext = "3gp";
            prefix = "audio_";
        } else if(type == FileType.MP4) {
            ext = "mp4";
            prefix = "video_";
        }

        File mediaFile = new File(mediaStorageDir.getPath() + File.separator + prefix + timeStamp + "." + ext);
        return mediaFile;
    }
}
